/**
 * TaggedPrinter.java Version 0.1, October 2001
 *
 * Copyright (C) 2001  Bas Peters (mail@bpeters.com)
 *
 * This file is part of James (Java MARC Events).
 *
 * James is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * James is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with James; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 **/

package com.bpeters.samples;

import java.io.*;
import com.bpeters.james.*;

public class TaggedPrinter {

    public static void main(String args[]) {
	if (args.length < 2) {
	    System.out.println("Usage: TaggedPrinter infile outfile");
	    return;
	}
	String infile = args[0];
	String outfile = args[1];

	MARCReader mr = new MARCReader();

	// Register the MARC reader class
	mr.setMARCHandler(new MARCHandlerTPImpl(outfile));

	// Register the error handler class
        mr.setErrorHandler(new ErrorHandlerTPImpl());

	// Send the file to the parse method
	try {
	    mr.parse(infile);
	} catch (Exception e) {
	    e.printStackTrace();
	}
    }

}

class MARCHandlerTPImpl implements MARCHandler {

    PrintWriter out;
    String outfile;

    public MARCHandlerTPImpl (String outfile) {
	this.outfile = outfile;
    }

    public void startTape() {
	try {
	    out = new PrintWriter(new FileWriter(outfile));
	} catch(IOException e) {
	    e.printStackTrace();
	}
    }

    public void endTape() {
	out.close();
    }

    public void startRecord(Leader leader) {
	out.println("Leader " + leader.toString());
    }

    public void endRecord() {
	out.println();
    }

    public void controlField(String tag, char[] chars) {
	String data = new String(chars);
	out.println(tag + " " + data);
    }

    public void startDataField(String tag, char ind1, char ind2) {
	out.print(tag + " " + ind1 + ind2);
    }

    public void endDataField(String tag) {
	out.println();
    }

    public void subfield(char code, char[] chars) {
	String data = new String(chars);
	out.print("$" + code + data);
    }

}

class ErrorHandlerTPImpl implements ErrorHandler {

    public void error(MARCException e) {
	System.out.println("Error: " + e.getMessage());
    }

    public void warning(MARCException e) {
	System.out.println("Warning: " + e.getMessage());
    }

    public void message(MARCException e) {
	System.out.println("Message: " + e.getMessage());
    }

    public void fatalError(MARCException e) {
	System.out.println("Fatal: " + e.getMessage());
    }

}

// End of TaggedPrinter.java
